@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: menu.py 867 2010-03-07 15:55:39Z icemac $
+# $Id: menu.py 1229 2011-01-29 17:07:16Z icemac $
 
 import zope.viewlet.manager
 import icemac.addressbook.browser.menus.interfaces
@@ -19,16 +19,21 @@ def getWeight((name, viewlet)):
         view_name = view_name[2:]
     view = zope.component.getMultiAdapter(
         (viewlet.context, viewlet.request), name=view_name)
-    entity = icemac.addressbook.interfaces.IEntity(view.interface)
-    orders = zope.component.queryUtility(
-        icemac.addressbook.interfaces.IOrderStorage)
-    if orders is None:
-        # outside address book
-        return 0
+    interface = getattr(view, 'interface', None)
+    if interface is None:
+        interface = getattr(view, 'interface_for_menu', None)
+    assert interface is not None, (
+        'View %r does neither have a non-null value on `interface` nor '
+        'on `interface_for_menu` attribute. But this is needed to compute '
+        'the AddMenu contents.' % view)
+    entity = icemac.addressbook.interfaces.IEntity(interface)
+    order = zope.component.getUtility(
+        icemac.addressbook.interfaces.IEntityOrder)
     try:
-        return orders.get(entity.name, icemac.addressbook.interfaces.ENTITIES)
-    except ValueError:
-        # there is no entity for the interface
+        return order.get(entity)
+    except (KeyError, zope.component.ComponentLookupError):
+        # The entity is not known in the order or we are outside an address
+        # book.
         return 0
 
 
