@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 1183 2010-11-23 17:17:09Z icemac $
+# $Id: interfaces.py 1229 2011-01-29 17:07:16Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
 import gocept.country
@@ -15,6 +15,7 @@ import zope.schema
 
 PACKAGE_ID = 'icemac.addressbook'
 ENTITIES = 'entites_namespace'
+FIELD_NS_PREFIX = 'fields-'
 
 
 class ITitle(zope.interface.Interface):
@@ -153,8 +154,8 @@ class IEntities(zope.interface.Interface):
         """
 
 
-class IEntity(zope.interface.Interface):
-    """Entity in the address book."""
+class IEntityRead(zope.interface.Interface):
+    """Entity in the address book. (Read only part of the interface.)"""
 
     title = zope.schema.TextLine(
         title=u"title of the entity", required=False)
@@ -177,22 +178,35 @@ class IEntity(zope.interface.Interface):
         field.
         """
 
-    def getRawFields():
-        """Get ordered name, field tuples of the schema fields on the entity.
+    def getFieldOrder():
+        """Get the ordered names of the fields.
 
-        Returnes static (zope.schema) and user defined (IField) fields.
+        Caution: This method only returns the names for the fields which are
+        known in the field order!
+        """
+
+    def getRawFields(sorted=True):
+        """Get (name, field) tuples of the schema fields on the entity.
+
+        When `sorted` is true the fields are sorted using the field order.
+
+        Returns static (zope.schema) and user defined (IField) fields.
 
         """
 
-    def getFieldsInOrder():
-        """Get ordered name, field tuples of the schema fields on the entity.
+    def getFields(sorted=True):
+        """Get (name, field) tuples of the schema fields on the entity.
+
+        When `sorted` is true the fields are sorted using the field order.
 
         Converts user defined fields (see IField) into zope.schema fields.
 
         """
 
-    def getFieldValuesInOrder():
-        """Get ordered list of the schema fields on the entity.
+    def getFieldValues(sorted=True):
+        """Get list of the schema fields on the entity.
+
+        When `sorted` is true the fields are sorted using the field order.
 
         Converts user defined fields (see IField) into zope.schema fields.
 
@@ -202,6 +216,34 @@ class IEntity(zope.interface.Interface):
         """Get the class object for `self.class_name`."""
 
 
+class IEntityWrite(zope.interface.Interface):
+    """Entity in the address book. (Write part of the interface.)"""
+
+    def addField(field):
+        """Add a user defined field to the entity."""
+
+    def setFieldOrder(field_names):
+        """Update the order of the fields like in `field_names`.
+
+        field_names ... list of the names of the fields as returned by
+                        `getFields`.
+
+        Field names which do not belong to the entity are omitted.
+        """
+
+
+class IEntity(IEntityRead, IEntityWrite):
+    """Entity in the address book."""
+
+
+class IEditableEntity(IEntity):
+    """Special entity which is editable.
+
+    This means that new fields can be added and the fields can be sorted.
+
+    """
+
+
 class IField(zope.interface.Interface):
     """User defined field."""
 
@@ -278,6 +320,12 @@ class IOrderStorageWrite(zope.interface.Interface):
         Raises a KeyError when the namespace does not exist.
         """
 
+    def truncate(namespace):
+        """Remove all objects from the order of a namespace.
+
+        Does nothing when the namespace is not known.
+        """
+
     def up(obj, namespace, delta=1):
         """Move the object one position up in the list.
 
