@@ -1,14 +1,12 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2010 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 783 2010-01-09 14:28:06Z icemac $
-
-import zope.interface
-import zope.schema
-
-import icemac.addressbook.principals.sources
+# $Id: interfaces.py 1229 2011-01-29 17:07:16Z icemac $
 
 from icemac.addressbook.i18n import MessageFactory as _
+import icemac.addressbook.principals.sources
+import zope.interface
+import zope.schema
 
 
 class IPasswordFields(zope.interface.Interface):
@@ -26,12 +24,13 @@ class IPasswordFields(zope.interface.Interface):
     def password_eq_repetition(obj):
         if obj.password != obj.password_repetition:
             raise zope.interface.Invalid(
-                _(u'Entry in password field was not equal to entry in password '
-                  u'repetition field.'))
+                _(u'Entry in password field was not equal to entry in '
+                  u'password repetition field.'))
 
 
 class IPrincipal(zope.interface.Interface):
-    "Derived from zope.app.authentication.principalfolder.IInternalPrincipal."
+    """Derived from
+    zope.pluggableauth.plugins.principalfolder.IInternalPrincipal."""
 
     person = zope.schema.Choice(
         title=_(u'person'), readonly=True,
@@ -58,7 +57,7 @@ class IRoles(zope.interface.Interface):
 
 
 class IRoot(zope.interface.Interface):
-    """Root object where on which global roles are stored.
+    """Root object on which global roles are stored.
 
     You have to provide an adapter from the root object to this interface.
     """
