@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2008-2009 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 473 2009-05-30 11:16:11Z mac $
+# $Id: tests.py 1229 2011-01-29 17:07:16Z icemac $
 
 import gocept.reference.verify
 import icemac.addressbook.principals.interfaces
@@ -22,11 +22,11 @@ class TestInterfaces(unittest.TestCase):
         gocept.reference.verify.verifyObject(
             icemac.addressbook.principals.interfaces.IPrincipal, principal)
         zope.interface.verify.verifyObject(
-            icemac.addressbook.principals.interfaces.IPasswordFields, principal)
+            icemac.addressbook.principals.interfaces.IPasswordFields,
+            principal)
         zope.interface.verify.verifyObject(
             icemac.addressbook.principals.interfaces.IRoles, principal)
 
 
 def test_suite():
     return icemac.addressbook.testing.AddressBookUnittestSuite(TestInterfaces)
-
