@@ -1,19 +1,23 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 827 2010-02-05 17:47:40Z icemac $
+# $Id: tests.py 1229 2011-01-29 17:07:16Z icemac $
 
 import icemac.addressbook.testing
 import zope.testing.renormalizing
 
+
 def test_suite():
     suite = icemac.addressbook.testing.FunctionalDocFileSuite(
+        "browser/about/about.txt",
         "browser/addressbook/addressbook.txt",
         "browser/authentication/login.txt",
         "browser/entities/bugfix.txt",
         "browser/entities/delete_choice_value.txt",
         "browser/entities/entities.txt",
         "browser/entities/file.txt",
+        "browser/entities/sortorder-fields.txt",
+        "browser/entities/sortorder.txt",
         "browser/export/export.txt",
         "browser/export/translation.txt",
         "browser/export/userfields.txt",
@@ -22,16 +26,17 @@ def test_suite():
         "browser/person/clone.txt",
         "browser/person/file.txt",
         "browser/person/person.txt",
+        "browser/person/sortorder.txt",
         "browser/person/translation.txt",
         "browser/principals/principals.txt",
         "browser/rootfolder/rootfolder.txt",
+        "browser/search/delete.txt",
         "browser/search/search.txt",
         )
     suite.addTest(
         icemac.addressbook.testing.FunctionalDocFileSuite(
-            # Tests which do not need the default <DATETIME> normalizer:
+            # Tests which must not run with the default <DATETIME> normalizer:
             "browser/metadata.txt",
             checker=zope.testing.renormalizing.RENormalizing([])
             ))
     return suite
-
