@@ -1,11 +1,11 @@
 # -*- coding: latin-1 -*-
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve1.py 783 2010-01-09 14:28:06Z icemac $
+# $Id: evolve1.py 1229 2011-01-29 17:07:16Z icemac $
 
 __docformat__ = "reStructuredText"
 
-import zope.app.generations.utility
+import zope.generations.utility
 
 import icemac.addressbook.interfaces
 import icemac.addressbook.person
@@ -23,15 +23,14 @@ def evolve(context):
     Defines references on persons.
     """
 
-    root = zope.app.generations.utility.getRootFolder(context)
+    root = zope.generations.utility.getRootFolder(context)
     # persons need gocept.reference which needs a local utility stored in root
 
     # persons
-    persons = zope.app.generations.utility.findObjectsProviding(
+    persons = zope.generations.utility.findObjectsProviding(
         root, icemac.addressbook.interfaces.IPerson)
     for person in persons:
         person_created_with_set_site(root, person, None)
 
     icemac.addressbook.generations.utils.update_address_book_infrastructure(
         context)
-
