@@ -1,23 +1,30 @@
-# Copyright (c) 2008-2010 Michael Howitz
+# Copyright (c) 2008-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 865 2010-03-07 15:52:31Z icemac $
+# $Id: utils.py 1229 2011-01-29 17:07:16Z icemac $
 
-import zope.app.generations.utility
+import zope.generations.utility
 import icemac.addressbook.interfaces
 import icemac.addressbook.addressbook
 import logging
 
+
 logger = logging.getLogger('evolve')
 
+
 def evolve_addressbooks(func):
     "Decorator which evolves address books."
     def decorated(context):
-        root = zope.app.generations.utility.getRootFolder(context)
-        addressbooks = zope.app.generations.utility.findObjectsProviding(
+        root = zope.generations.utility.getRootFolder(context)
+        addressbooks = zope.generations.utility.findObjectsProviding(
             root, icemac.addressbook.interfaces.IAddressBook)
         for addressbook in addressbooks:
             logger.info('evolving %r' % addressbook)
-            func(addressbook)
+            old_site = zope.site.hooks.getSite()
+            try:
+                zope.site.hooks.setSite(addressbook)
+                func(addressbook)
+            finally:
+                zope.site.hooks.setSite(old_site)
     return decorated
 
 
