@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
 
 import os.path
@@ -13,13 +13,14 @@ def check_prerequisites():
         print "ERROR: buildout.cfg already exists."
         print "       Please (re-)move the existing one and restart install."
         return False
-    if sys.version_info[:2] != (2, 5):
-        print "ERROR: icemac.addressbook currently only supports python 2.5,"
-        print "       but you try to install it using python %s.%s.%s." % (
+    if sys.version_info[:2] not in [(2, 5), (2, 6)]:
+        print "ERROR: icemac.addressbook currently supports python 2.5 and 2.6"
+        print "       But you try to install it using python %s.%s.%s." % (
             sys.version_info[:3])
         return False
     return True
 
+
 class Configurator(object):
     """Configure installation.
 
@@ -101,7 +102,6 @@ class Configurator(object):
         else:
             self._conf.set('migration', 'old_instance', '')
 
-
     def print_intro(self):
         print 'Welcome to icemac.addressbook installation'
         print
@@ -120,6 +120,9 @@ class Configurator(object):
             'Password for the administrator', 'admin', 'password')
         self.host = self.ask_user('Hostname', 'server', 'host')
         self.port = self.ask_user('Port number', 'server', 'port')
+        self.username = self.ask_user(
+            'Username whether process should run as different user otherwise '
+            'emtpy', 'server', 'username')
 
     def get_log_options(self):
         print ' Please choose Log-Handler:'
@@ -161,7 +164,7 @@ class Configurator(object):
         while True:
             package = self.ask_user(
                 'Package %s' % index, 'packages', 'package_%s' % index,
-                global_default = '')
+                global_default='')
             index += 1
             if not package:
                 break
@@ -182,8 +185,8 @@ class Configurator(object):
             'Old instance is running as a demon process', 'migration',
             'stop_server', values=yes_no)
         self.start_server = self.ask_user(
-            'New instance should be started as a demon process after migration',
-            'migration', 'start_server', values=yes_no)
+            'New instance should be started as a demon process after '
+            'migration', 'migration', 'start_server', values=yes_no)
 
     def create_admin_zcml(self):
         print 'creating admin.zcml ...'
@@ -214,6 +217,9 @@ class Configurator(object):
         buildout_cfg.add_section('deploy.ini')
         buildout_cfg.set('deploy.ini', 'host', self.host)
         buildout_cfg.set('deploy.ini', 'port', self.port)
+        if self.username:
+            buildout_cfg.add_section('zdaemon.conf')
+            buildout_cfg.set('zdaemon.conf', 'user', 'user %s' % self.username)
         log_handler = self.log_handler
         if log_handler == 'FileHandler':
             b_log_handler = log_handler
