@@ -1,16 +1,15 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2010 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
 
-
 import doctest
 import icemac.addressbook.namechooser.namechooser
 import zope.annotation.attribute
 import zope.testing.cleanup
-import zope.testing.testrunner.layer
+import zope.testrunner.layer
 
 
-class NameChooserLayer(zope.testing.testrunner.layer.UnitTests):
+class NameChooserLayer(zope.testrunner.layer.UnitTests):
     """Layer for name chooser tests."""
 
     @classmethod
@@ -29,4 +28,3 @@ def test_suite():
     suite = doctest.DocFileSuite('namechooser.txt')
     suite.layer = NameChooserLayer
     return suite
-
