@@ -1,32 +1,42 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009-2010 Michael Howitz
+# Copyright (c) 2009-2011 Michael Howitz
 # See also LICENSE.txt
-# $Id: testing.py 1009 2010-08-15 14:20:55Z icemac $
+# $Id: testing.py 1242 2011-02-03 19:32:44Z icemac $
 
-import doctest
+import gocept.selenium.grok
 import icemac.addressbook.address
 import icemac.addressbook.addressbook
+import icemac.addressbook.file.file
+import icemac.addressbook.interfaces
 import icemac.addressbook.keyword
 import icemac.addressbook.person
 import icemac.addressbook.principals.principals
 import icemac.addressbook.principals.sources
 import icemac.addressbook.utils
+import inspect
 import os
 import os.path
 import re
 import tempfile
 import unittest
+import z3c.etestbrowser.wsgi
 import zope.annotation.attribute
-import zope.app.testing.functional
+import zope.app.wsgi.testlayer
+import zope.component
+import zope.site.hooks
 import zope.testbrowser.browser
 import zope.testbrowser.interfaces
-import zope.testbrowser.testing
 import zope.testing.cleanup
 import zope.testing.renormalizing
-import zope.testing.testrunner.layer
+import zope.testrunner.layer
+
+if os.environ.get('ZOPETESTINGDOCTEST'):  # pragma: no cover
+    from zope.testing import doctest
+else:
+    import doctest
 
 
-class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
+class AddressBookUnitTests(zope.testrunner.layer.UnitTests):
     """Layer for gathering addressbook unit tests."""
 
     @classmethod
@@ -56,33 +66,48 @@ def AddressBookUnittestSuite(*classes):
     return suite
 
 
-# XXX zope.app.testing.functional.defineLayer benutzen
-ftesting_zcml = os.path.join(os.path.dirname(__file__), 'ftesting.zcml')
-FunctionalLayer = zope.app.testing.functional.ZCMLLayer(
-    ftesting_zcml, __name__, 'FunctionalLayer')
+FunctionalLayer = zope.app.wsgi.testlayer.BrowserLayer(icemac.addressbook)
+SeleniumLayer = gocept.selenium.grok.Layer(
+    icemac.addressbook, name='SeleniumLayer')
 
 
-class FunctionalTestCase(zope.app.testing.functional.FunctionalTestCase):
+class FunctionalTestCase(unittest.TestCase):
     """Base class for functional tests."""
 
     layer = FunctionalLayer
 
 
+class AddressBookFunctionalTestCase(FunctionalTestCase):
+    "Functional test case where the address book gets created in the set up."
+
+    def setUp(self):
+        super(AddressBookFunctionalTestCase, self).setUp()
+        self.old_site = zope.site.hooks.getSite()
+        zope.site.hooks.setSite(
+            icemac.addressbook.testing.create_addressbook(
+                parent=self.layer.getRootFolder()))
+
+    def tearDown(self):
+        super(AddressBookFunctionalTestCase, self).tearDown()
+        zope.site.hooks.setSite(self.old_site)
+
+
 def FunctionalDocFileSuite(*paths, **kw):
     kw['optionflags'] = (kw.get('optionflags', 0) |
                          doctest.ELLIPSIS |
                          doctest.NORMALIZE_WHITESPACE)
-    if kw.has_key('layer'):
+    if 'layer' in kw:
         layer = kw.pop('layer')
     else:
         layer = FunctionalLayer
-    if not kw.has_key('checker'):
+    globs = kw.setdefault('globs', {})
+    globs['getRootFolder'] = layer.getRootFolder
+    if 'checker' not in kw:
         kw['checker'] = zope.testing.renormalizing.RENormalizing([
             (re.compile(r'[0-9]{2}/[0-9]{2}/[0-9]{2} [0-9]{2}:[0-9]{2}'),
              '<DATETIME>')
             ])
-
-    suite = zope.app.testing.functional.FunctionalDocFileSuite(*paths, **kw)
+    suite = doctest.DocFileSuite(*paths, **kw)
     suite.layer = layer
     return suite
 
@@ -121,6 +146,18 @@ def get_all_control_names(browser=None, form=None):
     return _get_control_names(
         zope.testbrowser.interfaces.IControl, browser, form)
 
+
+def get_messages(browser):
+    """Return the info messages displayed in browser.
+
+    Returns string when there is exactly one message, list otherwise."""
+    if not isinstance(browser, z3c.etestbrowser.wsgi.ExtendedTestBrowser):
+        raise ValueError(
+            'browser must be z3c.etestbrowser.wsgi.ExtendedTestBrowser')
+    return [x.text
+            for x in browser.etree.xpath('//div[@id="info-messages"]/ul/li')]
+
+
 def in_out_widget_select(browser, control_name, select_controls):
     """Function to add a selection to an in-out-widget.
 
@@ -149,11 +186,20 @@ def write_temp_file(content, suffix):
 ### Helper functions to create objects in the database ###
 
 
-def create_addressbook(parent=None, name='ab', title=u'test address book'):
+def create_addressbook(name='ab', title=u'test address book', parent=None):
+    """Create an address book.
+
+    When parent is `None`, it gets created in the root folder of the data base.
+
+    """
     ab = icemac.addressbook.utils.create_obj(
         icemac.addressbook.addressbook.AddressBook, title=title)
+    frame = inspect.currentframe()
     if parent is None:
-        parent = zope.app.testing.functional.getRootFolder()
+        try:
+            parent = frame.f_back.f_globals['getRootFolder']()
+        finally:
+            del frame
     parent[name] = ab
     return ab
 
@@ -240,6 +286,15 @@ def create_phone_number(person, set_as_default=True, return_obj=True, **kw):
         return number
 
 
+@icemac.addressbook.utils.set_site
+def create_file(person, return_obj=True, **kw):
+    "Create a file object inside the `person`."
+    name = icemac.addressbook.utils.create_and_add(
+        person, icemac.addressbook.file.file.File, **kw)
+    if return_obj:
+        return person[name]
+
+
 @icemac.addressbook.utils.set_site
 def create(
     parent, entity_name, return_obj=False, set_as_default=False, *args, **kw):
@@ -265,9 +320,9 @@ def create(
 
 
 @icemac.addressbook.utils.set_site
-def create_user(ab, first_name, last_name, email, password, roles):
+def create_user(ab, first_name, last_name, email, password, roles, **kw):
     person = create_person(
-        ab, ab, last_name, first_name=first_name)
+        ab, ab, last_name, first_name=first_name, **kw)
     create_email_address(ab, person, email=email)
 
     role_factory = icemac.addressbook.principals.sources.role_source.factory
@@ -295,4 +350,4 @@ def create_field(entity_name, type, title, **kw):
         icemac.addressbook.entities.Field, type=type, title=title, **kw)
     entity = zope.component.getUtility(
         icemac.addressbook.interfaces.IEntity, name=entity_name)
-    icemac.addressbook.entities.store_and_register_field(field, entity)
+    entity.addField(field)
